if (typeof(window.console) == "undefined") { console = {}; console.log = console.warn = console.error = function(a) {}; }

document.addEventListener("DOMContentLoaded", function () {
});
